# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['IpamIpamResourceDiscoveryArgs', 'IpamIpamResourceDiscovery']

@pulumi.input_type
class IpamIpamResourceDiscoveryArgs:
    def __init__(__self__, *,
                 operating_region_lists: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 ipam_resource_discovery_description: Optional[pulumi.Input[builtins.str]] = None,
                 ipam_resource_discovery_name: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a IpamIpamResourceDiscovery resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] operating_region_lists: The list of operating regions for resource discovery.
        :param pulumi.Input[builtins.str] ipam_resource_discovery_description: The description of resource discovery.
        :param pulumi.Input[builtins.str] ipam_resource_discovery_name: The name of the resource
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: Label list information.
        """
        pulumi.set(__self__, "operating_region_lists", operating_region_lists)
        if ipam_resource_discovery_description is not None:
            pulumi.set(__self__, "ipam_resource_discovery_description", ipam_resource_discovery_description)
        if ipam_resource_discovery_name is not None:
            pulumi.set(__self__, "ipam_resource_discovery_name", ipam_resource_discovery_name)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="operatingRegionLists")
    def operating_region_lists(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        The list of operating regions for resource discovery.
        """
        return pulumi.get(self, "operating_region_lists")

    @operating_region_lists.setter
    def operating_region_lists(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "operating_region_lists", value)

    @property
    @pulumi.getter(name="ipamResourceDiscoveryDescription")
    def ipam_resource_discovery_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The description of resource discovery.
        """
        return pulumi.get(self, "ipam_resource_discovery_description")

    @ipam_resource_discovery_description.setter
    def ipam_resource_discovery_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipam_resource_discovery_description", value)

    @property
    @pulumi.getter(name="ipamResourceDiscoveryName")
    def ipam_resource_discovery_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the resource
        """
        return pulumi.get(self, "ipam_resource_discovery_name")

    @ipam_resource_discovery_name.setter
    def ipam_resource_discovery_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipam_resource_discovery_name", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the resource group
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Label list information.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _IpamIpamResourceDiscoveryState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 ipam_resource_discovery_description: Optional[pulumi.Input[builtins.str]] = None,
                 ipam_resource_discovery_name: Optional[pulumi.Input[builtins.str]] = None,
                 operating_region_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 region_id: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering IpamIpamResourceDiscovery resources.
        :param pulumi.Input[builtins.str] create_time: The time when the resource discovery was created.
        :param pulumi.Input[builtins.str] ipam_resource_discovery_description: The description of resource discovery.
        :param pulumi.Input[builtins.str] ipam_resource_discovery_name: The name of the resource
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] operating_region_lists: The list of operating regions for resource discovery.
        :param pulumi.Input[builtins.str] region_id: The region ID of the resource
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group
        :param pulumi.Input[builtins.str] status: The status of the resource discovery instance. Value:
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: Label list information.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if ipam_resource_discovery_description is not None:
            pulumi.set(__self__, "ipam_resource_discovery_description", ipam_resource_discovery_description)
        if ipam_resource_discovery_name is not None:
            pulumi.set(__self__, "ipam_resource_discovery_name", ipam_resource_discovery_name)
        if operating_region_lists is not None:
            pulumi.set(__self__, "operating_region_lists", operating_region_lists)
        if region_id is not None:
            pulumi.set(__self__, "region_id", region_id)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The time when the resource discovery was created.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="ipamResourceDiscoveryDescription")
    def ipam_resource_discovery_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The description of resource discovery.
        """
        return pulumi.get(self, "ipam_resource_discovery_description")

    @ipam_resource_discovery_description.setter
    def ipam_resource_discovery_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipam_resource_discovery_description", value)

    @property
    @pulumi.getter(name="ipamResourceDiscoveryName")
    def ipam_resource_discovery_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the resource
        """
        return pulumi.get(self, "ipam_resource_discovery_name")

    @ipam_resource_discovery_name.setter
    def ipam_resource_discovery_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipam_resource_discovery_name", value)

    @property
    @pulumi.getter(name="operatingRegionLists")
    def operating_region_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        The list of operating regions for resource discovery.
        """
        return pulumi.get(self, "operating_region_lists")

    @operating_region_lists.setter
    def operating_region_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "operating_region_lists", value)

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The region ID of the resource
        """
        return pulumi.get(self, "region_id")

    @region_id.setter
    def region_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region_id", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the resource group
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the resource discovery instance. Value:
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Label list information.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("alicloud:vpc/ipamIpamResourceDiscovery:IpamIpamResourceDiscovery")
class IpamIpamResourceDiscovery(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ipam_resource_discovery_description: Optional[pulumi.Input[builtins.str]] = None,
                 ipam_resource_discovery_name: Optional[pulumi.Input[builtins.str]] = None,
                 operating_region_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        Provides a Vpc Ipam Ipam Resource Discovery resource.

        IP Address Management Resource Discovery.

        For information about Vpc Ipam Ipam Resource Discovery and how to use it, see [What is Ipam Resource Discovery](https://next.api.alibabacloud.com/document/VpcIpam/2023-02-28/CreateIpamResourceDiscovery).

        > **NOTE:** Available since v1.243.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.resourcemanager.get_resource_groups()
        default_ipam_ipam_resource_discovery = alicloud.vpc.IpamIpamResourceDiscovery("default",
            operating_region_lists=["cn-hangzhou"],
            ipam_resource_discovery_description="This is a custom IPAM resource discovery.",
            ipam_resource_discovery_name="example_resource_discovery")
        ```

        ## Import

        Vpc Ipam Ipam Resource Discovery can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:vpc/ipamIpamResourceDiscovery:IpamIpamResourceDiscovery example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] ipam_resource_discovery_description: The description of resource discovery.
        :param pulumi.Input[builtins.str] ipam_resource_discovery_name: The name of the resource
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] operating_region_lists: The list of operating regions for resource discovery.
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: Label list information.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IpamIpamResourceDiscoveryArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Vpc Ipam Ipam Resource Discovery resource.

        IP Address Management Resource Discovery.

        For information about Vpc Ipam Ipam Resource Discovery and how to use it, see [What is Ipam Resource Discovery](https://next.api.alibabacloud.com/document/VpcIpam/2023-02-28/CreateIpamResourceDiscovery).

        > **NOTE:** Available since v1.243.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.resourcemanager.get_resource_groups()
        default_ipam_ipam_resource_discovery = alicloud.vpc.IpamIpamResourceDiscovery("default",
            operating_region_lists=["cn-hangzhou"],
            ipam_resource_discovery_description="This is a custom IPAM resource discovery.",
            ipam_resource_discovery_name="example_resource_discovery")
        ```

        ## Import

        Vpc Ipam Ipam Resource Discovery can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:vpc/ipamIpamResourceDiscovery:IpamIpamResourceDiscovery example <id>
        ```

        :param str resource_name: The name of the resource.
        :param IpamIpamResourceDiscoveryArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IpamIpamResourceDiscoveryArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ipam_resource_discovery_description: Optional[pulumi.Input[builtins.str]] = None,
                 ipam_resource_discovery_name: Optional[pulumi.Input[builtins.str]] = None,
                 operating_region_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IpamIpamResourceDiscoveryArgs.__new__(IpamIpamResourceDiscoveryArgs)

            __props__.__dict__["ipam_resource_discovery_description"] = ipam_resource_discovery_description
            __props__.__dict__["ipam_resource_discovery_name"] = ipam_resource_discovery_name
            if operating_region_lists is None and not opts.urn:
                raise TypeError("Missing required property 'operating_region_lists'")
            __props__.__dict__["operating_region_lists"] = operating_region_lists
            __props__.__dict__["resource_group_id"] = resource_group_id
            __props__.__dict__["tags"] = tags
            __props__.__dict__["create_time"] = None
            __props__.__dict__["region_id"] = None
            __props__.__dict__["status"] = None
        super(IpamIpamResourceDiscovery, __self__).__init__(
            'alicloud:vpc/ipamIpamResourceDiscovery:IpamIpamResourceDiscovery',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            ipam_resource_discovery_description: Optional[pulumi.Input[builtins.str]] = None,
            ipam_resource_discovery_name: Optional[pulumi.Input[builtins.str]] = None,
            operating_region_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            region_id: Optional[pulumi.Input[builtins.str]] = None,
            resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None) -> 'IpamIpamResourceDiscovery':
        """
        Get an existing IpamIpamResourceDiscovery resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] create_time: The time when the resource discovery was created.
        :param pulumi.Input[builtins.str] ipam_resource_discovery_description: The description of resource discovery.
        :param pulumi.Input[builtins.str] ipam_resource_discovery_name: The name of the resource
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] operating_region_lists: The list of operating regions for resource discovery.
        :param pulumi.Input[builtins.str] region_id: The region ID of the resource
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group
        :param pulumi.Input[builtins.str] status: The status of the resource discovery instance. Value:
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: Label list information.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IpamIpamResourceDiscoveryState.__new__(_IpamIpamResourceDiscoveryState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["ipam_resource_discovery_description"] = ipam_resource_discovery_description
        __props__.__dict__["ipam_resource_discovery_name"] = ipam_resource_discovery_name
        __props__.__dict__["operating_region_lists"] = operating_region_lists
        __props__.__dict__["region_id"] = region_id
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        return IpamIpamResourceDiscovery(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        The time when the resource discovery was created.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="ipamResourceDiscoveryDescription")
    def ipam_resource_discovery_description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The description of resource discovery.
        """
        return pulumi.get(self, "ipam_resource_discovery_description")

    @property
    @pulumi.getter(name="ipamResourceDiscoveryName")
    def ipam_resource_discovery_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The name of the resource
        """
        return pulumi.get(self, "ipam_resource_discovery_name")

    @property
    @pulumi.getter(name="operatingRegionLists")
    def operating_region_lists(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        The list of operating regions for resource discovery.
        """
        return pulumi.get(self, "operating_region_lists")

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> pulumi.Output[builtins.str]:
        """
        The region ID of the resource
        """
        return pulumi.get(self, "region_id")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the resource group
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        The status of the resource discovery instance. Value:
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        Label list information.
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetIpamIpamPoolCidrsResult',
    'AwaitableGetIpamIpamPoolCidrsResult',
    'get_ipam_ipam_pool_cidrs',
    'get_ipam_ipam_pool_cidrs_output',
]

@pulumi.output_type
class GetIpamIpamPoolCidrsResult:
    """
    A collection of values returned by getIpamIpamPoolCidrs.
    """
    def __init__(__self__, cidr=None, cidrs=None, id=None, ipam_pool_id=None, output_file=None):
        if cidr and not isinstance(cidr, str):
            raise TypeError("Expected argument 'cidr' to be a str")
        pulumi.set(__self__, "cidr", cidr)
        if cidrs and not isinstance(cidrs, list):
            raise TypeError("Expected argument 'cidrs' to be a list")
        pulumi.set(__self__, "cidrs", cidrs)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ipam_pool_id and not isinstance(ipam_pool_id, str):
            raise TypeError("Expected argument 'ipam_pool_id' to be a str")
        pulumi.set(__self__, "ipam_pool_id", ipam_pool_id)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)

    @property
    @pulumi.getter
    def cidr(self) -> Optional[builtins.str]:
        """
        The CIDR address segment to be preset.> currently, only IPv4 address segments are supported.
        """
        return pulumi.get(self, "cidr")

    @property
    @pulumi.getter
    def cidrs(self) -> Sequence['outputs.GetIpamIpamPoolCidrsCidrResult']:
        """
        A list of Ipam Pool Cidr Entries. Each element contains the following attributes:
        """
        return pulumi.get(self, "cidrs")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ipamPoolId")
    def ipam_pool_id(self) -> builtins.str:
        """
        The ID of the IPAM pool instance.
        """
        return pulumi.get(self, "ipam_pool_id")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")


class AwaitableGetIpamIpamPoolCidrsResult(GetIpamIpamPoolCidrsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIpamIpamPoolCidrsResult(
            cidr=self.cidr,
            cidrs=self.cidrs,
            id=self.id,
            ipam_pool_id=self.ipam_pool_id,
            output_file=self.output_file)


def get_ipam_ipam_pool_cidrs(cidr: Optional[builtins.str] = None,
                             ipam_pool_id: Optional[builtins.str] = None,
                             output_file: Optional[builtins.str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIpamIpamPoolCidrsResult:
    """
    This data source provides Vpc Ipam Ipam Pool Cidr available to the user.[What is Ipam Pool Cidr](https://next.api.alibabacloud.com/document/VpcIpam/2023-02-28/AddIpamPoolCidr)

    > **NOTE:** Available since v1.241.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform-example"
    default_ipam = alicloud.vpc.IpamIpam("defaultIpam", operating_region_lists=["cn-hangzhou"])
    default_ipam_pool = alicloud.vpc.IpamIpamPool("defaultIpamPool",
        ipam_scope_id=default_ipam.private_default_scope_id,
        pool_region_id=default_ipam.region_id,
        ip_version="IPv4")
    default_ipam_ipam_pool_cidr = alicloud.vpc.IpamIpamPoolCidr("default",
        cidr="10.0.0.0/8",
        ipam_pool_id=default_ipam_pool.id)
    default = alicloud.vpc.get_ipam_ipam_pool_cidrs_output(cidr="10.0.0.0/8",
        ipam_pool_id=default_ipam_ipam_pool_cidr.ipam_pool_id)
    pulumi.export("alicloudVpcIpamIpamPoolCidrExampleId", default.cidrs[0].id)
    ```


    :param builtins.str cidr: The CIDR address segment to be preset.> currently, only IPv4 address segments are supported.
    :param builtins.str ipam_pool_id: The ID of the IPAM pool instance.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['cidr'] = cidr
    __args__['ipamPoolId'] = ipam_pool_id
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:vpc/getIpamIpamPoolCidrs:getIpamIpamPoolCidrs', __args__, opts=opts, typ=GetIpamIpamPoolCidrsResult).value

    return AwaitableGetIpamIpamPoolCidrsResult(
        cidr=pulumi.get(__ret__, 'cidr'),
        cidrs=pulumi.get(__ret__, 'cidrs'),
        id=pulumi.get(__ret__, 'id'),
        ipam_pool_id=pulumi.get(__ret__, 'ipam_pool_id'),
        output_file=pulumi.get(__ret__, 'output_file'))
def get_ipam_ipam_pool_cidrs_output(cidr: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                    ipam_pool_id: Optional[pulumi.Input[builtins.str]] = None,
                                    output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetIpamIpamPoolCidrsResult]:
    """
    This data source provides Vpc Ipam Ipam Pool Cidr available to the user.[What is Ipam Pool Cidr](https://next.api.alibabacloud.com/document/VpcIpam/2023-02-28/AddIpamPoolCidr)

    > **NOTE:** Available since v1.241.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform-example"
    default_ipam = alicloud.vpc.IpamIpam("defaultIpam", operating_region_lists=["cn-hangzhou"])
    default_ipam_pool = alicloud.vpc.IpamIpamPool("defaultIpamPool",
        ipam_scope_id=default_ipam.private_default_scope_id,
        pool_region_id=default_ipam.region_id,
        ip_version="IPv4")
    default_ipam_ipam_pool_cidr = alicloud.vpc.IpamIpamPoolCidr("default",
        cidr="10.0.0.0/8",
        ipam_pool_id=default_ipam_pool.id)
    default = alicloud.vpc.get_ipam_ipam_pool_cidrs_output(cidr="10.0.0.0/8",
        ipam_pool_id=default_ipam_ipam_pool_cidr.ipam_pool_id)
    pulumi.export("alicloudVpcIpamIpamPoolCidrExampleId", default.cidrs[0].id)
    ```


    :param builtins.str cidr: The CIDR address segment to be preset.> currently, only IPv4 address segments are supported.
    :param builtins.str ipam_pool_id: The ID of the IPAM pool instance.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['cidr'] = cidr
    __args__['ipamPoolId'] = ipam_pool_id
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:vpc/getIpamIpamPoolCidrs:getIpamIpamPoolCidrs', __args__, opts=opts, typ=GetIpamIpamPoolCidrsResult)
    return __ret__.apply(lambda __response__: GetIpamIpamPoolCidrsResult(
        cidr=pulumi.get(__response__, 'cidr'),
        cidrs=pulumi.get(__response__, 'cidrs'),
        id=pulumi.get(__response__, 'id'),
        ipam_pool_id=pulumi.get(__response__, 'ipam_pool_id'),
        output_file=pulumi.get(__response__, 'output_file')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ExperimentPlanTemplateArgs', 'ExperimentPlanTemplate']

@pulumi.input_type
class ExperimentPlanTemplateArgs:
    def __init__(__self__, *,
                 privacy_level: pulumi.Input[builtins.str],
                 template_name: pulumi.Input[builtins.str],
                 template_pipelines: pulumi.Input[Sequence[pulumi.Input['ExperimentPlanTemplateTemplatePipelineArgs']]],
                 template_description: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a ExperimentPlanTemplate resource.
        :param pulumi.Input[builtins.str] privacy_level: Used to indicate the privacy level of the content or information. It can have the following optional parameters:
               - private: Indicates that the content is private and restricted to specific users or permission groups. Private content is usually not publicly displayed, and only authorized users can view or edit it.
               - public: Indicates that the content is public and can be accessed by anyone. Public content is usually viewable by all users and is suitable for sharing information or resources
        :param pulumi.Input[builtins.str] template_name: Help users identify and select specific templates.
        :param pulumi.Input[Sequence[pulumi.Input['ExperimentPlanTemplateTemplatePipelineArgs']]] template_pipelines: Representative Template Pipeline. See `template_pipeline` below.
        :param pulumi.Input[builtins.str] template_description: Describe the purpose of this template.
        """
        pulumi.set(__self__, "privacy_level", privacy_level)
        pulumi.set(__self__, "template_name", template_name)
        pulumi.set(__self__, "template_pipelines", template_pipelines)
        if template_description is not None:
            pulumi.set(__self__, "template_description", template_description)

    @property
    @pulumi.getter(name="privacyLevel")
    def privacy_level(self) -> pulumi.Input[builtins.str]:
        """
        Used to indicate the privacy level of the content or information. It can have the following optional parameters:
        - private: Indicates that the content is private and restricted to specific users or permission groups. Private content is usually not publicly displayed, and only authorized users can view or edit it.
        - public: Indicates that the content is public and can be accessed by anyone. Public content is usually viewable by all users and is suitable for sharing information or resources
        """
        return pulumi.get(self, "privacy_level")

    @privacy_level.setter
    def privacy_level(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "privacy_level", value)

    @property
    @pulumi.getter(name="templateName")
    def template_name(self) -> pulumi.Input[builtins.str]:
        """
        Help users identify and select specific templates.
        """
        return pulumi.get(self, "template_name")

    @template_name.setter
    def template_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "template_name", value)

    @property
    @pulumi.getter(name="templatePipelines")
    def template_pipelines(self) -> pulumi.Input[Sequence[pulumi.Input['ExperimentPlanTemplateTemplatePipelineArgs']]]:
        """
        Representative Template Pipeline. See `template_pipeline` below.
        """
        return pulumi.get(self, "template_pipelines")

    @template_pipelines.setter
    def template_pipelines(self, value: pulumi.Input[Sequence[pulumi.Input['ExperimentPlanTemplateTemplatePipelineArgs']]]):
        pulumi.set(self, "template_pipelines", value)

    @property
    @pulumi.getter(name="templateDescription")
    def template_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Describe the purpose of this template.
        """
        return pulumi.get(self, "template_description")

    @template_description.setter
    def template_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "template_description", value)


@pulumi.input_type
class _ExperimentPlanTemplateState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 privacy_level: Optional[pulumi.Input[builtins.str]] = None,
                 template_description: Optional[pulumi.Input[builtins.str]] = None,
                 template_id: Optional[pulumi.Input[builtins.str]] = None,
                 template_name: Optional[pulumi.Input[builtins.str]] = None,
                 template_pipelines: Optional[pulumi.Input[Sequence[pulumi.Input['ExperimentPlanTemplateTemplatePipelineArgs']]]] = None):
        """
        Input properties used for looking up and filtering ExperimentPlanTemplate resources.
        :param pulumi.Input[builtins.str] create_time: The creation time of the resource.
        :param pulumi.Input[builtins.str] privacy_level: Used to indicate the privacy level of the content or information. It can have the following optional parameters:
               - private: Indicates that the content is private and restricted to specific users or permission groups. Private content is usually not publicly displayed, and only authorized users can view or edit it.
               - public: Indicates that the content is public and can be accessed by anyone. Public content is usually viewable by all users and is suitable for sharing information or resources
        :param pulumi.Input[builtins.str] template_description: Describe the purpose of this template.
        :param pulumi.Input[builtins.str] template_id: The ID of the template.
        :param pulumi.Input[builtins.str] template_name: Help users identify and select specific templates.
        :param pulumi.Input[Sequence[pulumi.Input['ExperimentPlanTemplateTemplatePipelineArgs']]] template_pipelines: Representative Template Pipeline. See `template_pipeline` below.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if privacy_level is not None:
            pulumi.set(__self__, "privacy_level", privacy_level)
        if template_description is not None:
            pulumi.set(__self__, "template_description", template_description)
        if template_id is not None:
            pulumi.set(__self__, "template_id", template_id)
        if template_name is not None:
            pulumi.set(__self__, "template_name", template_name)
        if template_pipelines is not None:
            pulumi.set(__self__, "template_pipelines", template_pipelines)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The creation time of the resource.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="privacyLevel")
    def privacy_level(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Used to indicate the privacy level of the content or information. It can have the following optional parameters:
        - private: Indicates that the content is private and restricted to specific users or permission groups. Private content is usually not publicly displayed, and only authorized users can view or edit it.
        - public: Indicates that the content is public and can be accessed by anyone. Public content is usually viewable by all users and is suitable for sharing information or resources
        """
        return pulumi.get(self, "privacy_level")

    @privacy_level.setter
    def privacy_level(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "privacy_level", value)

    @property
    @pulumi.getter(name="templateDescription")
    def template_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Describe the purpose of this template.
        """
        return pulumi.get(self, "template_description")

    @template_description.setter
    def template_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "template_description", value)

    @property
    @pulumi.getter(name="templateId")
    def template_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the template.
        """
        return pulumi.get(self, "template_id")

    @template_id.setter
    def template_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "template_id", value)

    @property
    @pulumi.getter(name="templateName")
    def template_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Help users identify and select specific templates.
        """
        return pulumi.get(self, "template_name")

    @template_name.setter
    def template_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "template_name", value)

    @property
    @pulumi.getter(name="templatePipelines")
    def template_pipelines(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ExperimentPlanTemplateTemplatePipelineArgs']]]]:
        """
        Representative Template Pipeline. See `template_pipeline` below.
        """
        return pulumi.get(self, "template_pipelines")

    @template_pipelines.setter
    def template_pipelines(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ExperimentPlanTemplateTemplatePipelineArgs']]]]):
        pulumi.set(self, "template_pipelines", value)


@pulumi.type_token("alicloud:eflo/experimentPlanTemplate:ExperimentPlanTemplate")
class ExperimentPlanTemplate(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 privacy_level: Optional[pulumi.Input[builtins.str]] = None,
                 template_description: Optional[pulumi.Input[builtins.str]] = None,
                 template_name: Optional[pulumi.Input[builtins.str]] = None,
                 template_pipelines: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ExperimentPlanTemplateTemplatePipelineArgs', 'ExperimentPlanTemplateTemplatePipelineArgsDict']]]]] = None,
                 __props__=None):
        """
        Provides a Eflo Experiment Plan Template resource.

        For information about Eflo Experiment Plan Template and how to use it, see [What is Experiment Plan Template](https://www.alibabacloud.com/help/en/pai/developer-reference/api-eflo-cnp-2023-08-28-createexperimentplantemplate).

        > **NOTE:** Available since v1.248.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.eflo.ExperimentPlanTemplate("default",
            template_pipelines=[{
                "workload_id": 2,
                "workload_name": "MatMul",
                "env_params": {
                    "cpu_per_worker": 90,
                    "gpu_per_worker": 8,
                    "memory_per_worker": 500,
                    "share_memory": 500,
                    "worker_num": 1,
                    "py_torch_version": "1",
                    "gpu_driver_version": "1",
                    "cuda_version": "1",
                    "nccl_version": "1",
                },
                "pipeline_order": 1,
                "scene": "baseline",
            }],
            privacy_level="private",
            template_name=name,
            template_description=name)
        ```

        ## Import

        Eflo Experiment Plan Template can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:eflo/experimentPlanTemplate:ExperimentPlanTemplate example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] privacy_level: Used to indicate the privacy level of the content or information. It can have the following optional parameters:
               - private: Indicates that the content is private and restricted to specific users or permission groups. Private content is usually not publicly displayed, and only authorized users can view or edit it.
               - public: Indicates that the content is public and can be accessed by anyone. Public content is usually viewable by all users and is suitable for sharing information or resources
        :param pulumi.Input[builtins.str] template_description: Describe the purpose of this template.
        :param pulumi.Input[builtins.str] template_name: Help users identify and select specific templates.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ExperimentPlanTemplateTemplatePipelineArgs', 'ExperimentPlanTemplateTemplatePipelineArgsDict']]]] template_pipelines: Representative Template Pipeline. See `template_pipeline` below.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ExperimentPlanTemplateArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Eflo Experiment Plan Template resource.

        For information about Eflo Experiment Plan Template and how to use it, see [What is Experiment Plan Template](https://www.alibabacloud.com/help/en/pai/developer-reference/api-eflo-cnp-2023-08-28-createexperimentplantemplate).

        > **NOTE:** Available since v1.248.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.eflo.ExperimentPlanTemplate("default",
            template_pipelines=[{
                "workload_id": 2,
                "workload_name": "MatMul",
                "env_params": {
                    "cpu_per_worker": 90,
                    "gpu_per_worker": 8,
                    "memory_per_worker": 500,
                    "share_memory": 500,
                    "worker_num": 1,
                    "py_torch_version": "1",
                    "gpu_driver_version": "1",
                    "cuda_version": "1",
                    "nccl_version": "1",
                },
                "pipeline_order": 1,
                "scene": "baseline",
            }],
            privacy_level="private",
            template_name=name,
            template_description=name)
        ```

        ## Import

        Eflo Experiment Plan Template can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:eflo/experimentPlanTemplate:ExperimentPlanTemplate example <id>
        ```

        :param str resource_name: The name of the resource.
        :param ExperimentPlanTemplateArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ExperimentPlanTemplateArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 privacy_level: Optional[pulumi.Input[builtins.str]] = None,
                 template_description: Optional[pulumi.Input[builtins.str]] = None,
                 template_name: Optional[pulumi.Input[builtins.str]] = None,
                 template_pipelines: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ExperimentPlanTemplateTemplatePipelineArgs', 'ExperimentPlanTemplateTemplatePipelineArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ExperimentPlanTemplateArgs.__new__(ExperimentPlanTemplateArgs)

            if privacy_level is None and not opts.urn:
                raise TypeError("Missing required property 'privacy_level'")
            __props__.__dict__["privacy_level"] = privacy_level
            __props__.__dict__["template_description"] = template_description
            if template_name is None and not opts.urn:
                raise TypeError("Missing required property 'template_name'")
            __props__.__dict__["template_name"] = template_name
            if template_pipelines is None and not opts.urn:
                raise TypeError("Missing required property 'template_pipelines'")
            __props__.__dict__["template_pipelines"] = template_pipelines
            __props__.__dict__["create_time"] = None
            __props__.__dict__["template_id"] = None
        super(ExperimentPlanTemplate, __self__).__init__(
            'alicloud:eflo/experimentPlanTemplate:ExperimentPlanTemplate',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            privacy_level: Optional[pulumi.Input[builtins.str]] = None,
            template_description: Optional[pulumi.Input[builtins.str]] = None,
            template_id: Optional[pulumi.Input[builtins.str]] = None,
            template_name: Optional[pulumi.Input[builtins.str]] = None,
            template_pipelines: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ExperimentPlanTemplateTemplatePipelineArgs', 'ExperimentPlanTemplateTemplatePipelineArgsDict']]]]] = None) -> 'ExperimentPlanTemplate':
        """
        Get an existing ExperimentPlanTemplate resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] create_time: The creation time of the resource.
        :param pulumi.Input[builtins.str] privacy_level: Used to indicate the privacy level of the content or information. It can have the following optional parameters:
               - private: Indicates that the content is private and restricted to specific users or permission groups. Private content is usually not publicly displayed, and only authorized users can view or edit it.
               - public: Indicates that the content is public and can be accessed by anyone. Public content is usually viewable by all users and is suitable for sharing information or resources
        :param pulumi.Input[builtins.str] template_description: Describe the purpose of this template.
        :param pulumi.Input[builtins.str] template_id: The ID of the template.
        :param pulumi.Input[builtins.str] template_name: Help users identify and select specific templates.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ExperimentPlanTemplateTemplatePipelineArgs', 'ExperimentPlanTemplateTemplatePipelineArgsDict']]]] template_pipelines: Representative Template Pipeline. See `template_pipeline` below.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ExperimentPlanTemplateState.__new__(_ExperimentPlanTemplateState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["privacy_level"] = privacy_level
        __props__.__dict__["template_description"] = template_description
        __props__.__dict__["template_id"] = template_id
        __props__.__dict__["template_name"] = template_name
        __props__.__dict__["template_pipelines"] = template_pipelines
        return ExperimentPlanTemplate(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        The creation time of the resource.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="privacyLevel")
    def privacy_level(self) -> pulumi.Output[builtins.str]:
        """
        Used to indicate the privacy level of the content or information. It can have the following optional parameters:
        - private: Indicates that the content is private and restricted to specific users or permission groups. Private content is usually not publicly displayed, and only authorized users can view or edit it.
        - public: Indicates that the content is public and can be accessed by anyone. Public content is usually viewable by all users and is suitable for sharing information or resources
        """
        return pulumi.get(self, "privacy_level")

    @property
    @pulumi.getter(name="templateDescription")
    def template_description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Describe the purpose of this template.
        """
        return pulumi.get(self, "template_description")

    @property
    @pulumi.getter(name="templateId")
    def template_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the template.
        """
        return pulumi.get(self, "template_id")

    @property
    @pulumi.getter(name="templateName")
    def template_name(self) -> pulumi.Output[builtins.str]:
        """
        Help users identify and select specific templates.
        """
        return pulumi.get(self, "template_name")

    @property
    @pulumi.getter(name="templatePipelines")
    def template_pipelines(self) -> pulumi.Output[Sequence['outputs.ExperimentPlanTemplateTemplatePipeline']]:
        """
        Representative Template Pipeline. See `template_pipeline` below.
        """
        return pulumi.get(self, "template_pipelines")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetServerlessInstancesResult',
    'AwaitableGetServerlessInstancesResult',
    'get_serverless_instances',
    'get_serverless_instances_output',
]

@pulumi.output_type
class GetServerlessInstancesResult:
    """
    A collection of values returned by getServerlessInstances.
    """
    def __init__(__self__, db_instance_class=None, db_instance_description=None, enable_details=None, id=None, ids=None, instances=None, network_type=None, output_file=None, resource_group_id=None, status=None, tags=None, vpc_id=None, vswitch_id=None, zone_id=None):
        if db_instance_class and not isinstance(db_instance_class, str):
            raise TypeError("Expected argument 'db_instance_class' to be a str")
        pulumi.set(__self__, "db_instance_class", db_instance_class)
        if db_instance_description and not isinstance(db_instance_description, str):
            raise TypeError("Expected argument 'db_instance_description' to be a str")
        pulumi.set(__self__, "db_instance_description", db_instance_description)
        if enable_details and not isinstance(enable_details, bool):
            raise TypeError("Expected argument 'enable_details' to be a bool")
        pulumi.set(__self__, "enable_details", enable_details)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if instances and not isinstance(instances, list):
            raise TypeError("Expected argument 'instances' to be a list")
        pulumi.set(__self__, "instances", instances)
        if network_type and not isinstance(network_type, str):
            raise TypeError("Expected argument 'network_type' to be a str")
        pulumi.set(__self__, "network_type", network_type)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if resource_group_id and not isinstance(resource_group_id, str):
            raise TypeError("Expected argument 'resource_group_id' to be a str")
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)
        if vswitch_id and not isinstance(vswitch_id, str):
            raise TypeError("Expected argument 'vswitch_id' to be a str")
        pulumi.set(__self__, "vswitch_id", vswitch_id)
        if zone_id and not isinstance(zone_id, str):
            raise TypeError("Expected argument 'zone_id' to be a str")
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="dbInstanceClass")
    def db_instance_class(self) -> Optional[builtins.str]:
        return pulumi.get(self, "db_instance_class")

    @property
    @pulumi.getter(name="dbInstanceDescription")
    def db_instance_description(self) -> Optional[builtins.str]:
        return pulumi.get(self, "db_instance_description")

    @property
    @pulumi.getter(name="enableDetails")
    def enable_details(self) -> Optional[builtins.bool]:
        return pulumi.get(self, "enable_details")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter
    def instances(self) -> Sequence['outputs.GetServerlessInstancesInstanceResult']:
        return pulumi.get(self, "instances")

    @property
    @pulumi.getter(name="networkType")
    def network_type(self) -> Optional[builtins.str]:
        return pulumi.get(self, "network_type")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[builtins.str]:
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter
    def status(self) -> Optional[builtins.str]:
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, builtins.str]]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[builtins.str]:
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> Optional[builtins.str]:
        return pulumi.get(self, "vswitch_id")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[builtins.str]:
        return pulumi.get(self, "zone_id")


class AwaitableGetServerlessInstancesResult(GetServerlessInstancesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetServerlessInstancesResult(
            db_instance_class=self.db_instance_class,
            db_instance_description=self.db_instance_description,
            enable_details=self.enable_details,
            id=self.id,
            ids=self.ids,
            instances=self.instances,
            network_type=self.network_type,
            output_file=self.output_file,
            resource_group_id=self.resource_group_id,
            status=self.status,
            tags=self.tags,
            vpc_id=self.vpc_id,
            vswitch_id=self.vswitch_id,
            zone_id=self.zone_id)


def get_serverless_instances(db_instance_class: Optional[builtins.str] = None,
                             db_instance_description: Optional[builtins.str] = None,
                             enable_details: Optional[builtins.bool] = None,
                             ids: Optional[Sequence[builtins.str]] = None,
                             network_type: Optional[builtins.str] = None,
                             output_file: Optional[builtins.str] = None,
                             resource_group_id: Optional[builtins.str] = None,
                             status: Optional[builtins.str] = None,
                             tags: Optional[Mapping[str, builtins.str]] = None,
                             vpc_id: Optional[builtins.str] = None,
                             vswitch_id: Optional[builtins.str] = None,
                             zone_id: Optional[builtins.str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetServerlessInstancesResult:
    """
    This data source provides the Mongodb Serverless Instances of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.148.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.mongodb.get_serverless_instances(ids=["example_value"],
        db_instance_class="example_value",
        db_instance_description="example_value",
        network_type="VPC",
        resource_group_id="example_value",
        status="Running",
        vpc_id="example_value",
        vswitch_id="example_value",
        zone_id="example_value",
        tags={
            "Created": "MongodbServerlessInstance",
            "For": "TF",
        })
    pulumi.export("mongodbServerlessInstanceId1", example.instances[0].id)
    ```


    :param builtins.str db_instance_class: The db instance class.
    :param builtins.str db_instance_description: The db instance description.
    :param builtins.bool enable_details: Default to `false`. Set it to `true` can output more details about resource attributes.
    :param Sequence[builtins.str] ids: A list of Serverless Instance IDs.
    :param builtins.str network_type: The network type of the instance. Valid values: `Classic` or `VPC`.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str resource_group_id: The ID of the resource group.
    :param builtins.str status: The instance status. Valid values: `Creating`, `DBInstanceClassChanging`, `DBInstanceNetTypeChanging`, `Deleting`, `EngineVersionUpgrading`, `GuardSwitching`, `HASwitching`, `Importing`, `ImportingFromOthers`, `LinkSwitching`, `MinorVersionUpgrading`, `NodeCreating`, `NodeDeleting`, `Rebooting`, `Restoring`, `Running`, `SSLModifying`, `TDEModifying`, `TempDBInstanceCreating`, `Transing`, `TransingToOthers`, `released`.
    :param Mapping[str, builtins.str] tags: A mapping of tags to assign to the resource.
    :param builtins.str vpc_id: The ID of the VPC network.
    :param builtins.str vswitch_id: The id of the vswitch.
    :param builtins.str zone_id: The ID of the zone.
    """
    __args__ = dict()
    __args__['dbInstanceClass'] = db_instance_class
    __args__['dbInstanceDescription'] = db_instance_description
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['networkType'] = network_type
    __args__['outputFile'] = output_file
    __args__['resourceGroupId'] = resource_group_id
    __args__['status'] = status
    __args__['tags'] = tags
    __args__['vpcId'] = vpc_id
    __args__['vswitchId'] = vswitch_id
    __args__['zoneId'] = zone_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:mongodb/getServerlessInstances:getServerlessInstances', __args__, opts=opts, typ=GetServerlessInstancesResult).value

    return AwaitableGetServerlessInstancesResult(
        db_instance_class=pulumi.get(__ret__, 'db_instance_class'),
        db_instance_description=pulumi.get(__ret__, 'db_instance_description'),
        enable_details=pulumi.get(__ret__, 'enable_details'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        instances=pulumi.get(__ret__, 'instances'),
        network_type=pulumi.get(__ret__, 'network_type'),
        output_file=pulumi.get(__ret__, 'output_file'),
        resource_group_id=pulumi.get(__ret__, 'resource_group_id'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'),
        vswitch_id=pulumi.get(__ret__, 'vswitch_id'),
        zone_id=pulumi.get(__ret__, 'zone_id'))
def get_serverless_instances_output(db_instance_class: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                    db_instance_description: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                    enable_details: Optional[pulumi.Input[Optional[builtins.bool]]] = None,
                                    ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                                    network_type: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                    output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                    resource_group_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                    status: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                    tags: Optional[pulumi.Input[Optional[Mapping[str, builtins.str]]]] = None,
                                    vpc_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                    vswitch_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                    zone_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetServerlessInstancesResult]:
    """
    This data source provides the Mongodb Serverless Instances of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.148.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.mongodb.get_serverless_instances(ids=["example_value"],
        db_instance_class="example_value",
        db_instance_description="example_value",
        network_type="VPC",
        resource_group_id="example_value",
        status="Running",
        vpc_id="example_value",
        vswitch_id="example_value",
        zone_id="example_value",
        tags={
            "Created": "MongodbServerlessInstance",
            "For": "TF",
        })
    pulumi.export("mongodbServerlessInstanceId1", example.instances[0].id)
    ```


    :param builtins.str db_instance_class: The db instance class.
    :param builtins.str db_instance_description: The db instance description.
    :param builtins.bool enable_details: Default to `false`. Set it to `true` can output more details about resource attributes.
    :param Sequence[builtins.str] ids: A list of Serverless Instance IDs.
    :param builtins.str network_type: The network type of the instance. Valid values: `Classic` or `VPC`.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str resource_group_id: The ID of the resource group.
    :param builtins.str status: The instance status. Valid values: `Creating`, `DBInstanceClassChanging`, `DBInstanceNetTypeChanging`, `Deleting`, `EngineVersionUpgrading`, `GuardSwitching`, `HASwitching`, `Importing`, `ImportingFromOthers`, `LinkSwitching`, `MinorVersionUpgrading`, `NodeCreating`, `NodeDeleting`, `Rebooting`, `Restoring`, `Running`, `SSLModifying`, `TDEModifying`, `TempDBInstanceCreating`, `Transing`, `TransingToOthers`, `released`.
    :param Mapping[str, builtins.str] tags: A mapping of tags to assign to the resource.
    :param builtins.str vpc_id: The ID of the VPC network.
    :param builtins.str vswitch_id: The id of the vswitch.
    :param builtins.str zone_id: The ID of the zone.
    """
    __args__ = dict()
    __args__['dbInstanceClass'] = db_instance_class
    __args__['dbInstanceDescription'] = db_instance_description
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['networkType'] = network_type
    __args__['outputFile'] = output_file
    __args__['resourceGroupId'] = resource_group_id
    __args__['status'] = status
    __args__['tags'] = tags
    __args__['vpcId'] = vpc_id
    __args__['vswitchId'] = vswitch_id
    __args__['zoneId'] = zone_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:mongodb/getServerlessInstances:getServerlessInstances', __args__, opts=opts, typ=GetServerlessInstancesResult)
    return __ret__.apply(lambda __response__: GetServerlessInstancesResult(
        db_instance_class=pulumi.get(__response__, 'db_instance_class'),
        db_instance_description=pulumi.get(__response__, 'db_instance_description'),
        enable_details=pulumi.get(__response__, 'enable_details'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        instances=pulumi.get(__response__, 'instances'),
        network_type=pulumi.get(__response__, 'network_type'),
        output_file=pulumi.get(__response__, 'output_file'),
        resource_group_id=pulumi.get(__response__, 'resource_group_id'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        vpc_id=pulumi.get(__response__, 'vpc_id'),
        vswitch_id=pulumi.get(__response__, 'vswitch_id'),
        zone_id=pulumi.get(__response__, 'zone_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .account import *
from .backup_policy import *
from .connection import *
from .database import *
from .db_instance_ip_array import *
from .db_instance_plan import *
from .db_resource_group import *
from .elastic_instance import *
from .external_data_service import *
from .get_accounts import *
from .get_data_backups import *
from .get_db_instance_plans import *
from .get_instances import *
from .get_log_backups import *
from .get_zones import *
from .hadoop_data_source import *
from .instance import *
from .jdbc_data_source import *
from .remote_adb_data_source import *
from .streaming_data_service import *
from .streaming_data_source import *
from .streaming_job import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'HttpRequestHeaderModificationRuleRequestHeaderModification',
    'HttpResponseHeaderModificationRuleResponseHeaderModification',
    'OriginPoolOrigin',
    'OriginPoolOriginAuthConf',
    'RecordAuthConf',
    'RecordData',
    'SiteDeliveryTaskHttpDelivery',
    'SiteDeliveryTaskHttpDeliveryStandardAuthParam',
    'SiteDeliveryTaskKafkaDelivery',
    'SiteDeliveryTaskOssDelivery',
    'SiteDeliveryTaskS3Delivery',
    'SiteDeliveryTaskSlsDelivery',
    'WaitingRoomHostNameAndPath',
    'GetSitesSiteResult',
]

@pulumi.output_type
class HttpRequestHeaderModificationRuleRequestHeaderModification(dict):
    def __init__(__self__, *,
                 name: builtins.str,
                 operation: builtins.str,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str name: Request Header Name.
        :param builtins.str operation: Mode of operation. Value range:
        :param builtins.str value: Request header value
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "operation", operation)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Request Header Name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def operation(self) -> builtins.str:
        """
        Mode of operation. Value range:
        """
        return pulumi.get(self, "operation")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        Request header value
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class HttpResponseHeaderModificationRuleResponseHeaderModification(dict):
    def __init__(__self__, *,
                 name: builtins.str,
                 operation: builtins.str,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str name: The response header name.
        :param builtins.str operation: Operation method. Possible values:
        :param builtins.str value: The response header value.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "operation", operation)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        The response header name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def operation(self) -> builtins.str:
        """
        Operation method. Possible values:
        """
        return pulumi.get(self, "operation")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        The response header value.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class OriginPoolOrigin(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "authConf":
            suggest = "auth_conf"
        elif key == "originId":
            suggest = "origin_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in OriginPoolOrigin. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        OriginPoolOrigin.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        OriginPoolOrigin.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 address: Optional[builtins.str] = None,
                 auth_conf: Optional['outputs.OriginPoolOriginAuthConf'] = None,
                 enabled: Optional[builtins.bool] = None,
                 header: Optional[builtins.str] = None,
                 name: Optional[builtins.str] = None,
                 origin_id: Optional[builtins.int] = None,
                 type: Optional[builtins.str] = None,
                 weight: Optional[builtins.int] = None):
        """
        :param builtins.str address: Origin Address.
        :param 'OriginPoolOriginAuthConfArgs' auth_conf: The authentication information. When the source Station is an OSS or S3 and other source stations need to be authenticated, the authentication-related configuration information needs to be transmitted. See `auth_conf` below.
        :param builtins.bool enabled: Whether the source station is enabled:
        :param builtins.str header: The request header that is sent when returning to the source. Only Host is supported.
        :param builtins.str name: Origin Name.
        :param builtins.int origin_id: Origin ID.
        :param builtins.str type: Source station type:
               ip_domain: ip or domain name type origin station;
               - `OSS`:OSS address source station;
               - `S3`:AWS S3 Source station.
        :param builtins.int weight: Weight, 0-100.
        """
        if address is not None:
            pulumi.set(__self__, "address", address)
        if auth_conf is not None:
            pulumi.set(__self__, "auth_conf", auth_conf)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if header is not None:
            pulumi.set(__self__, "header", header)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if origin_id is not None:
            pulumi.set(__self__, "origin_id", origin_id)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if weight is not None:
            pulumi.set(__self__, "weight", weight)

    @property
    @pulumi.getter
    def address(self) -> Optional[builtins.str]:
        """
        Origin Address.
        """
        return pulumi.get(self, "address")

    @property
    @pulumi.getter(name="authConf")
    def auth_conf(self) -> Optional['outputs.OriginPoolOriginAuthConf']:
        """
        The authentication information. When the source Station is an OSS or S3 and other source stations need to be authenticated, the authentication-related configuration information needs to be transmitted. See `auth_conf` below.
        """
        return pulumi.get(self, "auth_conf")

    @property
    @pulumi.getter
    def enabled(self) -> Optional[builtins.bool]:
        """
        Whether the source station is enabled:
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter
    def header(self) -> Optional[builtins.str]:
        """
        The request header that is sent when returning to the source. Only Host is supported.
        """
        return pulumi.get(self, "header")

    @property
    @pulumi.getter
    def name(self) -> Optional[builtins.str]:
        """
        Origin Name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="originId")
    def origin_id(self) -> Optional[builtins.int]:
        """
        Origin ID.
        """
        return pulumi.get(self, "origin_id")

    @property
    @pulumi.getter
    def type(self) -> Optional[builtins.str]:
        """
        Source station type:
        ip_domain: ip or domain name type origin station;
        - `OSS`:OSS address source station;
        - `S3`:AWS S3 Source station.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def weight(self) -> Optional[builtins.int]:
        """
        Weight, 0-100.
        """
        return pulumi.get(self, "weight")


@pulumi.output_type
class OriginPoolOriginAuthConf(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "accessKey":
            suggest = "access_key"
        elif key == "authType":
            suggest = "auth_type"
        elif key == "secretKey":
            suggest = "secret_key"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in OriginPoolOriginAuthConf. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        OriginPoolOriginAuthConf.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        OriginPoolOriginAuthConf.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 access_key: Optional[builtins.str] = None,
                 auth_type: Optional[builtins.str] = None,
                 region: Optional[builtins.str] = None,
                 secret_key: Optional[builtins.str] = None,
                 version: Optional[builtins.str] = None):
        """
        :param builtins.str access_key: The AccessKey to be passed when AuthType is set to private_cross_account or private.
        :param builtins.str auth_type: Authentication type.
        :param builtins.str region: The Region of the source station to be transmitted when the source station is AWS S3.
        :param builtins.str secret_key: The SecretKey to be passed when AuthType is set to private_cross_account or private.
        :param builtins.str version: The signature version to be transmitted when the source station is AWS S3.
        """
        if access_key is not None:
            pulumi.set(__self__, "access_key", access_key)
        if auth_type is not None:
            pulumi.set(__self__, "auth_type", auth_type)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if secret_key is not None:
            pulumi.set(__self__, "secret_key", secret_key)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> Optional[builtins.str]:
        """
        The AccessKey to be passed when AuthType is set to private_cross_account or private.
        """
        return pulumi.get(self, "access_key")

    @property
    @pulumi.getter(name="authType")
    def auth_type(self) -> Optional[builtins.str]:
        """
        Authentication type.
        """
        return pulumi.get(self, "auth_type")

    @property
    @pulumi.getter
    def region(self) -> Optional[builtins.str]:
        """
        The Region of the source station to be transmitted when the source station is AWS S3.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> Optional[builtins.str]:
        """
        The SecretKey to be passed when AuthType is set to private_cross_account or private.
        """
        return pulumi.get(self, "secret_key")

    @property
    @pulumi.getter
    def version(self) -> Optional[builtins.str]:
        """
        The signature version to be transmitted when the source station is AWS S3.
        """
        return pulumi.get(self, "version")


@pulumi.output_type
class RecordAuthConf(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "accessKey":
            suggest = "access_key"
        elif key == "authType":
            suggest = "auth_type"
        elif key == "secretKey":
            suggest = "secret_key"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RecordAuthConf. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RecordAuthConf.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RecordAuthConf.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 access_key: Optional[builtins.str] = None,
                 auth_type: Optional[builtins.str] = None,
                 region: Optional[builtins.str] = None,
                 secret_key: Optional[builtins.str] = None,
                 version: Optional[builtins.str] = None):
        """
        :param builtins.str access_key: The access key of the account to which the origin server belongs. This parameter is required when the SourceType is OSS, and AuthType is private_same_account, or when the SourceType is S3 and AuthType is private.
        :param builtins.str auth_type: The authentication type of the origin server. Different origins support different authentication types. The type of origin refers to the SourceType parameter in this operation. If the type of origin is OSS or S3, you must specify the authentication type of the origin. Valid values:
        :param builtins.str region: The region of the origin. If the origin type is S3, you must specify this value. You can get the region information from the official website of S3.
        :param builtins.str secret_key: The secret access key of the account to which the origin server belongs. This parameter is required when the SourceType is OSS, and AuthType is private_same_account, or when the SourceType is S3 and AuthType is private.
        :param builtins.str version: The version of the signature algorithm. This parameter is required when the origin type is S3 and AuthType is private. The following two types are supported:
        """
        if access_key is not None:
            pulumi.set(__self__, "access_key", access_key)
        if auth_type is not None:
            pulumi.set(__self__, "auth_type", auth_type)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if secret_key is not None:
            pulumi.set(__self__, "secret_key", secret_key)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> Optional[builtins.str]:
        """
        The access key of the account to which the origin server belongs. This parameter is required when the SourceType is OSS, and AuthType is private_same_account, or when the SourceType is S3 and AuthType is private.
        """
        return pulumi.get(self, "access_key")

    @property
    @pulumi.getter(name="authType")
    def auth_type(self) -> Optional[builtins.str]:
        """
        The authentication type of the origin server. Different origins support different authentication types. The type of origin refers to the SourceType parameter in this operation. If the type of origin is OSS or S3, you must specify the authentication type of the origin. Valid values:
        """
        return pulumi.get(self, "auth_type")

    @property
    @pulumi.getter
    def region(self) -> Optional[builtins.str]:
        """
        The region of the origin. If the origin type is S3, you must specify this value. You can get the region information from the official website of S3.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> Optional[builtins.str]:
        """
        The secret access key of the account to which the origin server belongs. This parameter is required when the SourceType is OSS, and AuthType is private_same_account, or when the SourceType is S3 and AuthType is private.
        """
        return pulumi.get(self, "secret_key")

    @property
    @pulumi.getter
    def version(self) -> Optional[builtins.str]:
        """
        The version of the signature algorithm. This parameter is required when the origin type is S3 and AuthType is private. The following two types are supported:
        """
        return pulumi.get(self, "version")


@pulumi.output_type
class RecordData(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "keyTag":
            suggest = "key_tag"
        elif key == "matchingType":
            suggest = "matching_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RecordData. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RecordData.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RecordData.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 algorithm: Optional[builtins.int] = None,
                 certificate: Optional[builtins.str] = None,
                 fingerprint: Optional[builtins.str] = None,
                 flag: Optional[builtins.int] = None,
                 key_tag: Optional[builtins.int] = None,
                 matching_type: Optional[builtins.int] = None,
                 port: Optional[builtins.int] = None,
                 priority: Optional[builtins.int] = None,
                 selector: Optional[builtins.int] = None,
                 tag: Optional[builtins.str] = None,
                 type: Optional[builtins.int] = None,
                 usage: Optional[builtins.int] = None,
                 value: Optional[builtins.str] = None,
                 weight: Optional[builtins.int] = None):
        """
        :param builtins.int algorithm: The encryption algorithm used for the record, specified within the range from 0 to 255. This parameter is required when you add CERT or SSHFP records.
        :param builtins.str certificate: The public key of the certificate. This parameter is required when you add CERT, SMIMEA, or TLSA records.
        :param builtins.str fingerprint: The public key fingerprint of the record. This parameter is required when you add a SSHFP record.
        :param builtins.int flag: The flag bit of the record. The Flag for a CAA record indicates its priority and how it is processed, specified within the range of 0 to 255. This parameter is required when you add a CAA record.
        :param builtins.int key_tag: The public key identification for the record, specified within the range of 0 to 65,535. This parameter is required when you add a CAA record.
        :param builtins.int matching_type: The algorithm policy used to match or validate the certificate, specified within the range 0 to 255. This parameter is required when you add SMIMEA or TLSA records.
        :param builtins.int port: The port of the record, specified within the range of 0 to 65,535. This parameter is required when you add an SRV record.
        :param builtins.int priority: The priority of the record, specified within the range of 0 to 65,535. A smaller value indicates a higher priority. This parameter is required when you add MX, SRV, and URI records.
        :param builtins.int selector: The type of certificate or public key, specified within the range of 0 to 255. This parameter is required when you add SMIMEA or TLSA records.
        :param builtins.str tag: The label of the record. The Tag of a CAA record indicate its specific type and usage. This parameter is required when you add a CAA record.
        :param builtins.int type: The certificate type of the record (in CERT records), or the public key type (in SSHFP records). This parameter is required when you add CERT or SSHFP records.
        :param builtins.int usage: The usage identifier of the record, specified within the range of 0 to 255. This parameter is required when you add SMIMEA or TLSA records.
        :param builtins.str value: The record value or part of the record content. This parameter is required when you add A/AAAA, CNAME, NS, MX, TXT, CAA, SRV, and URI records. It has different meanings based on different types of records:
               
               - **A/AAAA**: the IP address(es). Separate multiple IPs with commas (,). You must have at least one IPv4 address.
               - `CNAME`: the target domain name.
               - `NS`: the name servers for the domain name.
               - `MX`: a valid domain name of the target mail server.
               - `TXT`: a valid text string.
               - `CAA`: a valid domain name of the certificate authority.
               - `SRV`: a valid domain name of the target host.
               - `URI`: a valid URI string.
        :param builtins.int weight: The weight of the record, specified within the range of 0 to 65,535. This parameter is required when you add SRV or URI records.
        """
        if algorithm is not None:
            pulumi.set(__self__, "algorithm", algorithm)
        if certificate is not None:
            pulumi.set(__self__, "certificate", certificate)
        if fingerprint is not None:
            pulumi.set(__self__, "fingerprint", fingerprint)
        if flag is not None:
            pulumi.set(__self__, "flag", flag)
        if key_tag is not None:
            pulumi.set(__self__, "key_tag", key_tag)
        if matching_type is not None:
            pulumi.set(__self__, "matching_type", matching_type)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if selector is not None:
            pulumi.set(__self__, "selector", selector)
        if tag is not None:
            pulumi.set(__self__, "tag", tag)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if usage is not None:
            pulumi.set(__self__, "usage", usage)
        if value is not None:
            pulumi.set(__self__, "value", value)
        if weight is not None:
            pulumi.set(__self__, "weight", weight)

    @property
    @pulumi.getter
    def algorithm(self) -> Optional[builtins.int]:
        """
        The encryption algorithm used for the record, specified within the range from 0 to 255. This parameter is required when you add CERT or SSHFP records.
        """
        return pulumi.get(self, "algorithm")

    @property
    @pulumi.getter
    def certificate(self) -> Optional[builtins.str]:
        """
        The public key of the certificate. This parameter is required when you add CERT, SMIMEA, or TLSA records.
        """
        return pulumi.get(self, "certificate")

    @property
    @pulumi.getter
    def fingerprint(self) -> Optional[builtins.str]:
        """
        The public key fingerprint of the record. This parameter is required when you add a SSHFP record.
        """
        return pulumi.get(self, "fingerprint")

    @property
    @pulumi.getter
    def flag(self) -> Optional[builtins.int]:
        """
        The flag bit of the record. The Flag for a CAA record indicates its priority and how it is processed, specified within the range of 0 to 255. This parameter is required when you add a CAA record.
        """
        return pulumi.get(self, "flag")

    @property
    @pulumi.getter(name="keyTag")
    def key_tag(self) -> Optional[builtins.int]:
        """
        The public key identification for the record, specified within the range of 0 to 65,535. This parameter is required when you add a CAA record.
        """
        return pulumi.get(self, "key_tag")

    @property
    @pulumi.getter(name="matchingType")
    def matching_type(self) -> Optional[builtins.int]:
        """
        The algorithm policy used to match or validate the certificate, specified within the range 0 to 255. This parameter is required when you add SMIMEA or TLSA records.
        """
        return pulumi.get(self, "matching_type")

    @property
    @pulumi.getter
    def port(self) -> Optional[builtins.int]:
        """
        The port of the record, specified within the range of 0 to 65,535. This parameter is required when you add an SRV record.
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter
    def priority(self) -> Optional[builtins.int]:
        """
        The priority of the record, specified within the range of 0 to 65,535. A smaller value indicates a higher priority. This parameter is required when you add MX, SRV, and URI records.
        """
        return pulumi.get(self, "priority")

    @property
    @pulumi.getter
    def selector(self) -> Optional[builtins.int]:
        """
        The type of certificate or public key, specified within the range of 0 to 255. This parameter is required when you add SMIMEA or TLSA records.
        """
        return pulumi.get(self, "selector")

    @property
    @pulumi.getter
    def tag(self) -> Optional[builtins.str]:
        """
        The label of the record. The Tag of a CAA record indicate its specific type and usage. This parameter is required when you add a CAA record.
        """
        return pulumi.get(self, "tag")

    @property
    @pulumi.getter
    def type(self) -> Optional[builtins.int]:
        """
        The certificate type of the record (in CERT records), or the public key type (in SSHFP records). This parameter is required when you add CERT or SSHFP records.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def usage(self) -> Optional[builtins.int]:
        """
        The usage identifier of the record, specified within the range of 0 to 255. This parameter is required when you add SMIMEA or TLSA records.
        """
        return pulumi.get(self, "usage")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        The record value or part of the record content. This parameter is required when you add A/AAAA, CNAME, NS, MX, TXT, CAA, SRV, and URI records. It has different meanings based on different types of records:

        - **A/AAAA**: the IP address(es). Separate multiple IPs with commas (,). You must have at least one IPv4 address.
        - `CNAME`: the target domain name.
        - `NS`: the name servers for the domain name.
        - `MX`: a valid domain name of the target mail server.
        - `TXT`: a valid text string.
        - `CAA`: a valid domain name of the certificate authority.
        - `SRV`: a valid domain name of the target host.
        - `URI`: a valid URI string.
        """
        return pulumi.get(self, "value")

    @property
    @pulumi.getter
    def weight(self) -> Optional[builtins.int]:
        """
        The weight of the record, specified within the range of 0 to 65,535. This parameter is required when you add SRV or URI records.
        """
        return pulumi.get(self, "weight")


@pulumi.output_type
class SiteDeliveryTaskHttpDelivery(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "destUrl":
            suggest = "dest_url"
        elif key == "headerParam":
            suggest = "header_param"
        elif key == "logBodyPrefix":
            suggest = "log_body_prefix"
        elif key == "logBodySuffix":
            suggest = "log_body_suffix"
        elif key == "maxBatchMb":
            suggest = "max_batch_mb"
        elif key == "maxBatchSize":
            suggest = "max_batch_size"
        elif key == "maxRetry":
            suggest = "max_retry"
        elif key == "queryParam":
            suggest = "query_param"
        elif key == "standardAuthOn":
            suggest = "standard_auth_on"
        elif key == "standardAuthParam":
            suggest = "standard_auth_param"
        elif key == "transformTimeout":
            suggest = "transform_timeout"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SiteDeliveryTaskHttpDelivery. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SiteDeliveryTaskHttpDelivery.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SiteDeliveryTaskHttpDelivery.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 compress: Optional[builtins.str] = None,
                 dest_url: Optional[builtins.str] = None,
                 header_param: Optional[Mapping[str, builtins.str]] = None,
                 log_body_prefix: Optional[builtins.str] = None,
                 log_body_suffix: Optional[builtins.str] = None,
                 max_batch_mb: Optional[builtins.int] = None,
                 max_batch_size: Optional[builtins.int] = None,
                 max_retry: Optional[builtins.int] = None,
                 query_param: Optional[Mapping[str, builtins.str]] = None,
                 standard_auth_on: Optional[builtins.bool] = None,
                 standard_auth_param: Optional['outputs.SiteDeliveryTaskHttpDeliveryStandardAuthParam'] = None,
                 transform_timeout: Optional[builtins.int] = None):
        """
        :param 'SiteDeliveryTaskHttpDeliveryStandardAuthParamArgs' standard_auth_param: See `standard_auth_param` below.
        """
        if compress is not None:
            pulumi.set(__self__, "compress", compress)
        if dest_url is not None:
            pulumi.set(__self__, "dest_url", dest_url)
        if header_param is not None:
            pulumi.set(__self__, "header_param", header_param)
        if log_body_prefix is not None:
            pulumi.set(__self__, "log_body_prefix", log_body_prefix)
        if log_body_suffix is not None:
            pulumi.set(__self__, "log_body_suffix", log_body_suffix)
        if max_batch_mb is not None:
            pulumi.set(__self__, "max_batch_mb", max_batch_mb)
        if max_batch_size is not None:
            pulumi.set(__self__, "max_batch_size", max_batch_size)
        if max_retry is not None:
            pulumi.set(__self__, "max_retry", max_retry)
        if query_param is not None:
            pulumi.set(__self__, "query_param", query_param)
        if standard_auth_on is not None:
            pulumi.set(__self__, "standard_auth_on", standard_auth_on)
        if standard_auth_param is not None:
            pulumi.set(__self__, "standard_auth_param", standard_auth_param)
        if transform_timeout is not None:
            pulumi.set(__self__, "transform_timeout", transform_timeout)

    @property
    @pulumi.getter
    def compress(self) -> Optional[builtins.str]:
        return pulumi.get(self, "compress")

    @property
    @pulumi.getter(name="destUrl")
    def dest_url(self) -> Optional[builtins.str]:
        return pulumi.get(self, "dest_url")

    @property
    @pulumi.getter(name="headerParam")
    def header_param(self) -> Optional[Mapping[str, builtins.str]]:
        return pulumi.get(self, "header_param")

    @property
    @pulumi.getter(name="logBodyPrefix")
    def log_body_prefix(self) -> Optional[builtins.str]:
        return pulumi.get(self, "log_body_prefix")

    @property
    @pulumi.getter(name="logBodySuffix")
    def log_body_suffix(self) -> Optional[builtins.str]:
        return pulumi.get(self, "log_body_suffix")

    @property
    @pulumi.getter(name="maxBatchMb")
    def max_batch_mb(self) -> Optional[builtins.int]:
        return pulumi.get(self, "max_batch_mb")

    @property
    @pulumi.getter(name="maxBatchSize")
    def max_batch_size(self) -> Optional[builtins.int]:
        return pulumi.get(self, "max_batch_size")

    @property
    @pulumi.getter(name="maxRetry")
    def max_retry(self) -> Optional[builtins.int]:
        return pulumi.get(self, "max_retry")

    @property
    @pulumi.getter(name="queryParam")
    def query_param(self) -> Optional[Mapping[str, builtins.str]]:
        return pulumi.get(self, "query_param")

    @property
    @pulumi.getter(name="standardAuthOn")
    def standard_auth_on(self) -> Optional[builtins.bool]:
        return pulumi.get(self, "standard_auth_on")

    @property
    @pulumi.getter(name="standardAuthParam")
    def standard_auth_param(self) -> Optional['outputs.SiteDeliveryTaskHttpDeliveryStandardAuthParam']:
        """
        See `standard_auth_param` below.
        """
        return pulumi.get(self, "standard_auth_param")

    @property
    @pulumi.getter(name="transformTimeout")
    def transform_timeout(self) -> Optional[builtins.int]:
        return pulumi.get(self, "transform_timeout")


@pulumi.output_type
class SiteDeliveryTaskHttpDeliveryStandardAuthParam(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "expiredTime":
            suggest = "expired_time"
        elif key == "privateKey":
            suggest = "private_key"
        elif key == "urlPath":
            suggest = "url_path"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SiteDeliveryTaskHttpDeliveryStandardAuthParam. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SiteDeliveryTaskHttpDeliveryStandardAuthParam.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SiteDeliveryTaskHttpDeliveryStandardAuthParam.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 expired_time: Optional[builtins.int] = None,
                 private_key: Optional[builtins.str] = None,
                 url_path: Optional[builtins.str] = None):
        if expired_time is not None:
            pulumi.set(__self__, "expired_time", expired_time)
        if private_key is not None:
            pulumi.set(__self__, "private_key", private_key)
        if url_path is not None:
            pulumi.set(__self__, "url_path", url_path)

    @property
    @pulumi.getter(name="expiredTime")
    def expired_time(self) -> Optional[builtins.int]:
        return pulumi.get(self, "expired_time")

    @property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> Optional[builtins.str]:
        return pulumi.get(self, "private_key")

    @property
    @pulumi.getter(name="urlPath")
    def url_path(self) -> Optional[builtins.str]:
        return pulumi.get(self, "url_path")


@pulumi.output_type
class SiteDeliveryTaskKafkaDelivery(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "machanismType":
            suggest = "machanism_type"
        elif key == "userAuth":
            suggest = "user_auth"
        elif key == "userName":
            suggest = "user_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SiteDeliveryTaskKafkaDelivery. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SiteDeliveryTaskKafkaDelivery.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SiteDeliveryTaskKafkaDelivery.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 balancer: Optional[builtins.str] = None,
                 brokers: Optional[Sequence[builtins.str]] = None,
                 compress: Optional[builtins.str] = None,
                 machanism_type: Optional[builtins.str] = None,
                 password: Optional[builtins.str] = None,
                 topic: Optional[builtins.str] = None,
                 user_auth: Optional[builtins.bool] = None,
                 user_name: Optional[builtins.str] = None):
        """
        :param builtins.str compress: The compression method. By default, data is not compressed.
        """
        if balancer is not None:
            pulumi.set(__self__, "balancer", balancer)
        if brokers is not None:
            pulumi.set(__self__, "brokers", brokers)
        if compress is not None:
            pulumi.set(__self__, "compress", compress)
        if machanism_type is not None:
            pulumi.set(__self__, "machanism_type", machanism_type)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if topic is not None:
            pulumi.set(__self__, "topic", topic)
        if user_auth is not None:
            pulumi.set(__self__, "user_auth", user_auth)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter
    def balancer(self) -> Optional[builtins.str]:
        return pulumi.get(self, "balancer")

    @property
    @pulumi.getter
    def brokers(self) -> Optional[Sequence[builtins.str]]:
        return pulumi.get(self, "brokers")

    @property
    @pulumi.getter
    def compress(self) -> Optional[builtins.str]:
        """
        The compression method. By default, data is not compressed.
        """
        return pulumi.get(self, "compress")

    @property
    @pulumi.getter(name="machanismType")
    def machanism_type(self) -> Optional[builtins.str]:
        return pulumi.get(self, "machanism_type")

    @property
    @pulumi.getter
    def password(self) -> Optional[builtins.str]:
        return pulumi.get(self, "password")

    @property
    @pulumi.getter
    def topic(self) -> Optional[builtins.str]:
        return pulumi.get(self, "topic")

    @property
    @pulumi.getter(name="userAuth")
    def user_auth(self) -> Optional[builtins.bool]:
        return pulumi.get(self, "user_auth")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[builtins.str]:
        return pulumi.get(self, "user_name")


@pulumi.output_type
class SiteDeliveryTaskOssDelivery(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "bucketName":
            suggest = "bucket_name"
        elif key == "prefixPath":
            suggest = "prefix_path"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SiteDeliveryTaskOssDelivery. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SiteDeliveryTaskOssDelivery.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SiteDeliveryTaskOssDelivery.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 aliuid: Optional[builtins.str] = None,
                 bucket_name: Optional[builtins.str] = None,
                 prefix_path: Optional[builtins.str] = None,
                 region: Optional[builtins.str] = None):
        """
        :param builtins.str region: The region ID of the service.
        """
        if aliuid is not None:
            pulumi.set(__self__, "aliuid", aliuid)
        if bucket_name is not None:
            pulumi.set(__self__, "bucket_name", bucket_name)
        if prefix_path is not None:
            pulumi.set(__self__, "prefix_path", prefix_path)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @property
    @pulumi.getter
    def aliuid(self) -> Optional[builtins.str]:
        return pulumi.get(self, "aliuid")

    @property
    @pulumi.getter(name="bucketName")
    def bucket_name(self) -> Optional[builtins.str]:
        return pulumi.get(self, "bucket_name")

    @property
    @pulumi.getter(name="prefixPath")
    def prefix_path(self) -> Optional[builtins.str]:
        return pulumi.get(self, "prefix_path")

    @property
    @pulumi.getter
    def region(self) -> Optional[builtins.str]:
        """
        The region ID of the service.
        """
        return pulumi.get(self, "region")


@pulumi.output_type
class SiteDeliveryTaskS3Delivery(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "accessKey":
            suggest = "access_key"
        elif key == "bucketPath":
            suggest = "bucket_path"
        elif key == "prefixPath":
            suggest = "prefix_path"
        elif key == "s3Cmpt":
            suggest = "s3_cmpt"
        elif key == "secretKey":
            suggest = "secret_key"
        elif key == "serverSideEncryption":
            suggest = "server_side_encryption"
        elif key == "vertifyType":
            suggest = "vertify_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SiteDeliveryTaskS3Delivery. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SiteDeliveryTaskS3Delivery.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SiteDeliveryTaskS3Delivery.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 access_key: Optional[builtins.str] = None,
                 bucket_path: Optional[builtins.str] = None,
                 endpoint: Optional[builtins.str] = None,
                 prefix_path: Optional[builtins.str] = None,
                 region: Optional[builtins.str] = None,
                 s3_cmpt: Optional[builtins.bool] = None,
                 secret_key: Optional[builtins.str] = None,
                 server_side_encryption: Optional[builtins.bool] = None,
                 vertify_type: Optional[builtins.str] = None):
        """
        :param builtins.bool server_side_encryption: Server-side encryption
        :param builtins.str vertify_type: Authentication Type
        """
        if access_key is not None:
            pulumi.set(__self__, "access_key", access_key)
        if bucket_path is not None:
            pulumi.set(__self__, "bucket_path", bucket_path)
        if endpoint is not None:
            pulumi.set(__self__, "endpoint", endpoint)
        if prefix_path is not None:
            pulumi.set(__self__, "prefix_path", prefix_path)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if s3_cmpt is not None:
            pulumi.set(__self__, "s3_cmpt", s3_cmpt)
        if secret_key is not None:
            pulumi.set(__self__, "secret_key", secret_key)
        if server_side_encryption is not None:
            pulumi.set(__self__, "server_side_encryption", server_side_encryption)
        if vertify_type is not None:
            pulumi.set(__self__, "vertify_type", vertify_type)

    @property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> Optional[builtins.str]:
        return pulumi.get(self, "access_key")

    @property
    @pulumi.getter(name="bucketPath")
    def bucket_path(self) -> Optional[builtins.str]:
        return pulumi.get(self, "bucket_path")

    @property
    @pulumi.getter
    def endpoint(self) -> Optional[builtins.str]:
        return pulumi.get(self, "endpoint")

    @property
    @pulumi.getter(name="prefixPath")
    def prefix_path(self) -> Optional[builtins.str]:
        return pulumi.get(self, "prefix_path")

    @property
    @pulumi.getter
    def region(self) -> Optional[builtins.str]:
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="s3Cmpt")
    def s3_cmpt(self) -> Optional[builtins.bool]:
        return pulumi.get(self, "s3_cmpt")

    @property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> Optional[builtins.str]:
        return pulumi.get(self, "secret_key")

    @property
    @pulumi.getter(name="serverSideEncryption")
    def server_side_encryption(self) -> Optional[builtins.bool]:
        """
        Server-side encryption
        """
        return pulumi.get(self, "server_side_encryption")

    @property
    @pulumi.getter(name="vertifyType")
    def vertify_type(self) -> Optional[builtins.str]:
        """
        Authentication Type
        """
        return pulumi.get(self, "vertify_type")


@pulumi.output_type
class SiteDeliveryTaskSlsDelivery(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "slsLogStore":
            suggest = "sls_log_store"
        elif key == "slsProject":
            suggest = "sls_project"
        elif key == "slsRegion":
            suggest = "sls_region"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SiteDeliveryTaskSlsDelivery. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SiteDeliveryTaskSlsDelivery.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SiteDeliveryTaskSlsDelivery.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 sls_log_store: Optional[builtins.str] = None,
                 sls_project: Optional[builtins.str] = None,
                 sls_region: Optional[builtins.str] = None):
        if sls_log_store is not None:
            pulumi.set(__self__, "sls_log_store", sls_log_store)
        if sls_project is not None:
            pulumi.set(__self__, "sls_project", sls_project)
        if sls_region is not None:
            pulumi.set(__self__, "sls_region", sls_region)

    @property
    @pulumi.getter(name="slsLogStore")
    def sls_log_store(self) -> Optional[builtins.str]:
        return pulumi.get(self, "sls_log_store")

    @property
    @pulumi.getter(name="slsProject")
    def sls_project(self) -> Optional[builtins.str]:
        return pulumi.get(self, "sls_project")

    @property
    @pulumi.getter(name="slsRegion")
    def sls_region(self) -> Optional[builtins.str]:
        return pulumi.get(self, "sls_region")


@pulumi.output_type
class WaitingRoomHostNameAndPath(dict):
    def __init__(__self__, *,
                 domain: builtins.str,
                 path: builtins.str,
                 subdomain: builtins.str):
        """
        :param builtins.str domain: The domain name.
        :param builtins.str path: The path.
        :param builtins.str subdomain: The subdomain.
        """
        pulumi.set(__self__, "domain", domain)
        pulumi.set(__self__, "path", path)
        pulumi.set(__self__, "subdomain", subdomain)

    @property
    @pulumi.getter
    def domain(self) -> builtins.str:
        """
        The domain name.
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter
    def path(self) -> builtins.str:
        """
        The path.
        """
        return pulumi.get(self, "path")

    @property
    @pulumi.getter
    def subdomain(self) -> builtins.str:
        """
        The subdomain.
        """
        return pulumi.get(self, "subdomain")


@pulumi.output_type
class GetSitesSiteResult(dict):
    def __init__(__self__, *,
                 access_type: builtins.str,
                 coverage: builtins.str,
                 create_time: builtins.str,
                 id: builtins.int,
                 instance_id: builtins.str,
                 modify_time: builtins.str,
                 name_server_list: builtins.str,
                 resource_group_id: builtins.str,
                 site_id: builtins.int,
                 site_name: builtins.str,
                 status: builtins.str):
        """
        :param builtins.str access_type: Access type. Value:-**NS**: Managed access via NS.-**CNAME**: access through CNAME.
        :param builtins.str coverage: Acceleration area
        :param builtins.str create_time: Creation time
        :param builtins.int id: The ID of the resource supplied above.
        :param builtins.str instance_id: The ID of the associated package instance.
        :param builtins.str modify_time: Modification time
        :param builtins.str name_server_list: Site Resolution Name Server List
        :param builtins.str resource_group_id: The ID of the resource group
        :param builtins.int site_id: Site ID
        :param builtins.str site_name: Site Name
        :param builtins.str status: The status of the resource
        """
        pulumi.set(__self__, "access_type", access_type)
        pulumi.set(__self__, "coverage", coverage)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "modify_time", modify_time)
        pulumi.set(__self__, "name_server_list", name_server_list)
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        pulumi.set(__self__, "site_id", site_id)
        pulumi.set(__self__, "site_name", site_name)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="accessType")
    def access_type(self) -> builtins.str:
        """
        Access type. Value:-**NS**: Managed access via NS.-**CNAME**: access through CNAME.
        """
        return pulumi.get(self, "access_type")

    @property
    @pulumi.getter
    def coverage(self) -> builtins.str:
        """
        Acceleration area
        """
        return pulumi.get(self, "coverage")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        Creation time
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def id(self) -> builtins.int:
        """
        The ID of the resource supplied above.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        The ID of the associated package instance.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="modifyTime")
    def modify_time(self) -> builtins.str:
        """
        Modification time
        """
        return pulumi.get(self, "modify_time")

    @property
    @pulumi.getter(name="nameServerList")
    def name_server_list(self) -> builtins.str:
        """
        Site Resolution Name Server List
        """
        return pulumi.get(self, "name_server_list")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> builtins.str:
        """
        The ID of the resource group
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> builtins.int:
        """
        Site ID
        """
        return pulumi.get(self, "site_id")

    @property
    @pulumi.getter(name="siteName")
    def site_name(self) -> builtins.str:
        """
        Site Name
        """
        return pulumi.get(self, "site_name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['WafDomainArgs', 'WafDomain']

@pulumi.input_type
class WafDomainArgs:
    def __init__(__self__, *,
                 domain_name: pulumi.Input[builtins.str],
                 client_ip_tag: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a WafDomain resource.
        :param pulumi.Input[builtins.str] domain_name: The accelerated domain name.
        :param pulumi.Input[builtins.str] client_ip_tag: The client ip tag.
        """
        pulumi.set(__self__, "domain_name", domain_name)
        if client_ip_tag is not None:
            pulumi.set(__self__, "client_ip_tag", client_ip_tag)

    @property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> pulumi.Input[builtins.str]:
        """
        The accelerated domain name.
        """
        return pulumi.get(self, "domain_name")

    @domain_name.setter
    def domain_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "domain_name", value)

    @property
    @pulumi.getter(name="clientIpTag")
    def client_ip_tag(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The client ip tag.
        """
        return pulumi.get(self, "client_ip_tag")

    @client_ip_tag.setter
    def client_ip_tag(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "client_ip_tag", value)


@pulumi.input_type
class _WafDomainState:
    def __init__(__self__, *,
                 client_ip_tag: Optional[pulumi.Input[builtins.str]] = None,
                 domain_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering WafDomain resources.
        :param pulumi.Input[builtins.str] client_ip_tag: The client ip tag.
        :param pulumi.Input[builtins.str] domain_name: The accelerated domain name.
        """
        if client_ip_tag is not None:
            pulumi.set(__self__, "client_ip_tag", client_ip_tag)
        if domain_name is not None:
            pulumi.set(__self__, "domain_name", domain_name)

    @property
    @pulumi.getter(name="clientIpTag")
    def client_ip_tag(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The client ip tag.
        """
        return pulumi.get(self, "client_ip_tag")

    @client_ip_tag.setter
    def client_ip_tag(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "client_ip_tag", value)

    @property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The accelerated domain name.
        """
        return pulumi.get(self, "domain_name")

    @domain_name.setter
    def domain_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "domain_name", value)


@pulumi.type_token("alicloud:dcdn/wafDomain:WafDomain")
class WafDomain(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 client_ip_tag: Optional[pulumi.Input[builtins.str]] = None,
                 domain_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a DCDN Waf Domain resource.

        For information about DCDN Waf Domain and how to use it, see [What is Waf Domain](https://www.alibabacloud.com/help/en/dcdn/developer-reference/api-dcdn-2018-01-15-batchsetdcdnwafdomainconfigs).

        > **NOTE:** Available since v1.185.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        domain_name = config.get("domainName")
        if domain_name is None:
            domain_name = "tf-example.com"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        example = alicloud.dcdn.Domain("example",
            domain_name=f"{domain_name}-{default['result']}",
            scope="overseas",
            sources=[{
                "content": "1.1.1.1",
                "port": 80,
                "priority": "20",
                "type": "ipaddr",
                "weight": "10",
            }])
        example_waf_domain = alicloud.dcdn.WafDomain("example",
            domain_name=example.domain_name,
            client_ip_tag="X-Forwarded-For")
        ```

        ## Import

        DCDN Waf Domain can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dcdn/wafDomain:WafDomain example <domain_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] client_ip_tag: The client ip tag.
        :param pulumi.Input[builtins.str] domain_name: The accelerated domain name.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: WafDomainArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a DCDN Waf Domain resource.

        For information about DCDN Waf Domain and how to use it, see [What is Waf Domain](https://www.alibabacloud.com/help/en/dcdn/developer-reference/api-dcdn-2018-01-15-batchsetdcdnwafdomainconfigs).

        > **NOTE:** Available since v1.185.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        domain_name = config.get("domainName")
        if domain_name is None:
            domain_name = "tf-example.com"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        example = alicloud.dcdn.Domain("example",
            domain_name=f"{domain_name}-{default['result']}",
            scope="overseas",
            sources=[{
                "content": "1.1.1.1",
                "port": 80,
                "priority": "20",
                "type": "ipaddr",
                "weight": "10",
            }])
        example_waf_domain = alicloud.dcdn.WafDomain("example",
            domain_name=example.domain_name,
            client_ip_tag="X-Forwarded-For")
        ```

        ## Import

        DCDN Waf Domain can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dcdn/wafDomain:WafDomain example <domain_name>
        ```

        :param str resource_name: The name of the resource.
        :param WafDomainArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(WafDomainArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 client_ip_tag: Optional[pulumi.Input[builtins.str]] = None,
                 domain_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = WafDomainArgs.__new__(WafDomainArgs)

            __props__.__dict__["client_ip_tag"] = client_ip_tag
            if domain_name is None and not opts.urn:
                raise TypeError("Missing required property 'domain_name'")
            __props__.__dict__["domain_name"] = domain_name
        super(WafDomain, __self__).__init__(
            'alicloud:dcdn/wafDomain:WafDomain',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            client_ip_tag: Optional[pulumi.Input[builtins.str]] = None,
            domain_name: Optional[pulumi.Input[builtins.str]] = None) -> 'WafDomain':
        """
        Get an existing WafDomain resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] client_ip_tag: The client ip tag.
        :param pulumi.Input[builtins.str] domain_name: The accelerated domain name.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _WafDomainState.__new__(_WafDomainState)

        __props__.__dict__["client_ip_tag"] = client_ip_tag
        __props__.__dict__["domain_name"] = domain_name
        return WafDomain(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="clientIpTag")
    def client_ip_tag(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The client ip tag.
        """
        return pulumi.get(self, "client_ip_tag")

    @property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> pulumi.Output[builtins.str]:
        """
        The accelerated domain name.
        """
        return pulumi.get(self, "domain_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['VscArgs', 'Vsc']

@pulumi.input_type
class VscArgs:
    def __init__(__self__, *,
                 node_id: pulumi.Input[builtins.str],
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 vsc_name: Optional[pulumi.Input[builtins.str]] = None,
                 vsc_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Vsc resource.
        :param pulumi.Input[builtins.str] node_id: The ID of the Node.
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource.
        :param pulumi.Input[builtins.str] vsc_name: The name of the Vsc.
        :param pulumi.Input[builtins.str] vsc_type: The type of the Vsc. Default value: `primary`. Valid values: `primary`.
        """
        pulumi.set(__self__, "node_id", node_id)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if vsc_name is not None:
            pulumi.set(__self__, "vsc_name", vsc_name)
        if vsc_type is not None:
            pulumi.set(__self__, "vsc_type", vsc_type)

    @property
    @pulumi.getter(name="nodeId")
    def node_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the Node.
        """
        return pulumi.get(self, "node_id")

    @node_id.setter
    def node_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "node_id", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        The tag of the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="vscName")
    def vsc_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the Vsc.
        """
        return pulumi.get(self, "vsc_name")

    @vsc_name.setter
    def vsc_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vsc_name", value)

    @property
    @pulumi.getter(name="vscType")
    def vsc_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of the Vsc. Default value: `primary`. Valid values: `primary`.
        """
        return pulumi.get(self, "vsc_type")

    @vsc_type.setter
    def vsc_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vsc_type", value)


@pulumi.input_type
class _VscState:
    def __init__(__self__, *,
                 node_id: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 vsc_name: Optional[pulumi.Input[builtins.str]] = None,
                 vsc_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Vsc resources.
        :param pulumi.Input[builtins.str] node_id: The ID of the Node.
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[builtins.str] status: The status of the Vsc.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource.
        :param pulumi.Input[builtins.str] vsc_name: The name of the Vsc.
        :param pulumi.Input[builtins.str] vsc_type: The type of the Vsc. Default value: `primary`. Valid values: `primary`.
        """
        if node_id is not None:
            pulumi.set(__self__, "node_id", node_id)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if vsc_name is not None:
            pulumi.set(__self__, "vsc_name", vsc_name)
        if vsc_type is not None:
            pulumi.set(__self__, "vsc_type", vsc_type)

    @property
    @pulumi.getter(name="nodeId")
    def node_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the Node.
        """
        return pulumi.get(self, "node_id")

    @node_id.setter
    def node_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "node_id", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the Vsc.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        The tag of the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="vscName")
    def vsc_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the Vsc.
        """
        return pulumi.get(self, "vsc_name")

    @vsc_name.setter
    def vsc_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vsc_name", value)

    @property
    @pulumi.getter(name="vscType")
    def vsc_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of the Vsc. Default value: `primary`. Valid values: `primary`.
        """
        return pulumi.get(self, "vsc_type")

    @vsc_type.setter
    def vsc_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vsc_type", value)


@pulumi.type_token("alicloud:eflo/vsc:Vsc")
class Vsc(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 node_id: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 vsc_name: Optional[pulumi.Input[builtins.str]] = None,
                 vsc_type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Eflo Vsc resource.

        Virtual Storage Channel.

        For information about Eflo Vsc and how to use it, see [What is Vsc](https://www.alibabacloud.com/help/en/pai/developer-reference/api-eflo-controller-2022-12-15-createvsc).

        > **NOTE:** Available since v1.250.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.eflo.Vsc("default",
            vsc_type="primary",
            node_id="e01-cn-9me49omda01",
            vsc_name=name)
        ```

        ## Import

        Eflo Vsc can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:eflo/vsc:Vsc example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] node_id: The ID of the Node.
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource.
        :param pulumi.Input[builtins.str] vsc_name: The name of the Vsc.
        :param pulumi.Input[builtins.str] vsc_type: The type of the Vsc. Default value: `primary`. Valid values: `primary`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VscArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Eflo Vsc resource.

        Virtual Storage Channel.

        For information about Eflo Vsc and how to use it, see [What is Vsc](https://www.alibabacloud.com/help/en/pai/developer-reference/api-eflo-controller-2022-12-15-createvsc).

        > **NOTE:** Available since v1.250.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.eflo.Vsc("default",
            vsc_type="primary",
            node_id="e01-cn-9me49omda01",
            vsc_name=name)
        ```

        ## Import

        Eflo Vsc can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:eflo/vsc:Vsc example <id>
        ```

        :param str resource_name: The name of the resource.
        :param VscArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VscArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 node_id: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 vsc_name: Optional[pulumi.Input[builtins.str]] = None,
                 vsc_type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VscArgs.__new__(VscArgs)

            if node_id is None and not opts.urn:
                raise TypeError("Missing required property 'node_id'")
            __props__.__dict__["node_id"] = node_id
            __props__.__dict__["resource_group_id"] = resource_group_id
            __props__.__dict__["tags"] = tags
            __props__.__dict__["vsc_name"] = vsc_name
            __props__.__dict__["vsc_type"] = vsc_type
            __props__.__dict__["status"] = None
        super(Vsc, __self__).__init__(
            'alicloud:eflo/vsc:Vsc',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            node_id: Optional[pulumi.Input[builtins.str]] = None,
            resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
            vsc_name: Optional[pulumi.Input[builtins.str]] = None,
            vsc_type: Optional[pulumi.Input[builtins.str]] = None) -> 'Vsc':
        """
        Get an existing Vsc resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] node_id: The ID of the Node.
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[builtins.str] status: The status of the Vsc.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource.
        :param pulumi.Input[builtins.str] vsc_name: The name of the Vsc.
        :param pulumi.Input[builtins.str] vsc_type: The type of the Vsc. Default value: `primary`. Valid values: `primary`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VscState.__new__(_VscState)

        __props__.__dict__["node_id"] = node_id
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["vsc_name"] = vsc_name
        __props__.__dict__["vsc_type"] = vsc_type
        return Vsc(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="nodeId")
    def node_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the Node.
        """
        return pulumi.get(self, "node_id")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        The status of the Vsc.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        The tag of the resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="vscName")
    def vsc_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The name of the Vsc.
        """
        return pulumi.get(self, "vsc_name")

    @property
    @pulumi.getter(name="vscType")
    def vsc_type(self) -> pulumi.Output[builtins.str]:
        """
        The type of the Vsc. Default value: `primary`. Valid values: `primary`.
        """
        return pulumi.get(self, "vsc_type")

